# System

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**agent** | [**SystemAgent**](SystemAgent.md) |  | [optional] 
**arch** | **str** |  | [optional] 
**ciphers** | **list[str]** |  | [optional] 
**credentials** | **str** |  | [optional] 
**engine_id** | **str** |  | [optional] 
**host** | **str** |  | [optional] 
**integrationinstanceid** | **str** |  | [optional] 
**issharedagent** | **bool** |  | [optional] 
**name** | **str** |  | [optional] 
**os** | **str** |  | [optional] 
**password** | **str** |  | [optional] 
**smb** | **int** |  | [optional] 
**smbport** | **int** |  | [optional] 
**sshkey** | **str** |  | [optional] 
**sshport** | **int** |  | [optional] 
**terminal_options** | [**TerminalOptions**](TerminalOptions.md) |  | [optional] 
**user** | **str** |  | [optional] 
**workgroup** | **str** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


